@@ -203,9 +203,11 @@ class DictContainsAllOf(Matcher):
 
 
 class InAnyOrder(Matcher):
-    """A Matcher checking that a Sequence contains *exactly* the passed items, in any order.
+    """A Matcher checking that an Iterable contains *exactly* the passed items, in any order.
 
-    :param values: A Sequence containing the expected items, in any order.
+    The Iterable can be for example a list, tuple or set. Items do not need to be hashable.
+
+    :param values: An Iterable containing the expected items, in any order.
 
     Usage:
       >>> from pychoir import InAnyOrder
@@ -216,7 +218,7 @@ class InAnyOrder(Matcher):
       >>> [{'a': 1}, {'b': 2}] == InAnyOrder([{'b': 2}, {'a': 1}])
       True
     """
-    def __init__(self, values: Sequence[Any]):
+    def __init__(self, values: Iterable[Any]):
         super().__init__()
         self.expected_values = values
 
@@ -233,6 +235,32 @@ class InAnyOrder(Matcher):
         return repr(self.expected_values)
 
 
+class SetEquals(Matcher):
+    """A Matcher checking that an Iterable has the expected items, duplicates ignored.
+    Faster than :class:`InAnyOrder` but less pedantic about duplicates and requires hashable items.
+
+    The Iterable can be for example a list, tuple or set. Items must be hashable.
+
+    :param values: An Iterable containing the expected items, in any order.
+
+    Usage:
+      >>> from pychoir import SetEquals
+      >>> [1, 2, 3, 3] == SetEquals([3, 2, 1])
+      True
+      >>> [1, 2] == SetEquals([3, 2, 1])
+      False
+    """
+    def __init__(self, values: Iterable[Any]):
+        super().__init__()
+        self.expected_values = values
+
+    def _matches(self, other: Iterable[Any]) -> bool:
+        return set(self.expected_values) == set(other)
+
+    def _description(self) -> str:
+        return repr(self.expected_values)
+
+
 class _NotPresent:
     def __str__(self) -> str:
         return 'NotPresent'
